pub fn get_arrow_schema_bytes(
py: Python<'_>,
cls: &Bound<'_, PyType>,
) -> PyResult<Py<PyBytes>>Expand description
Returns an Arrow IPC stream containing the Rust schema for the given data class.
Errors
Returns a PyErr if the class name is not recognized or schema serialization fails.